<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Concerns\HasTimestamps;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

/**
 * @property int    $id
 * @property string $name
 * @property string $short_name
 * @property string $type
 * @property string $siren
 * @property bool   $active
 * @property string $website
 * @property string $info
 */
class Organization extends Model
{
    use HasFactory;
    use HasTimestamps;

    public function users(): HasMany
    {
        return $this->hasMany(User::class);
    }

    public function address(): BelongsTo
    {
        return $this->belongsTo(Address::class);
    }

    function referent(): BelongsTo
    {
        return $this->belongsTo(Contact::class, 'referent_id');
    }

    function referentCyber(): BelongsTo
    {
        return $this->belongsTo(Contact::class, 'referent_cyber_id');
    }

    function referentElu(): BelongsTo
    {
        return $this->belongsTo(Contact::class, 'referent_elu_id');
    }
}
